// components/ProjectQuoteForm.tsx
import { useState } from 'react';

const steps = ['Contact details', 'Project details', 'Budget', 'Review'];

const FirstForm: React.FC = () => {
  const [currentStep, setCurrentStep] = useState(1);

  const renderStep = () => {
    switch (currentStep) {
      case 1:
        return <ContactDetailsStep />;
      // Add cases for other steps
      default:
        return null;
    }
  };

  return (
    <div className="max-w-2xl mx-auto p-6">
      <h1 className="text-3xl font-bold text-center mb-6">Get a project quote</h1>
      <p className="text-center mb-8 text-gray-600">
        Please fill the form below to receive a quote for your project. Feel free to add as much detail as needed.
      </p>
      
      <div className="mb-8">
        <div className="flex justify-between">
          {steps.map((step, index) => (
            <div key={step} className="flex items-center">
              <div className={`w-8 h-8 rounded-full flex items-center justify-center ${
                index + 1 <= currentStep ? 'bg-indigo-600 text-white' : 'bg-gray-200 text-gray-600'
              }`}>
                {index + 1}
              </div>
              {index < steps.length - 1 && (
                <div className={`h-1 w-16 ${
                  index + 1 < currentStep ? 'bg-indigo-600' : 'bg-gray-200'
                }`} />
              )}
            </div>
          ))}
        </div>
      </div>

      {renderStep()}

      <div className="mt-8 flex justify-end">
        <button
          className="bg-indigo-600 text-white px-6 py-2 rounded-md hover:bg-indigo-700 transition-colors"
          onClick={() => setCurrentStep(currentStep + 1)}
        >
          Next step
        </button>
      </div>
    </div>
  );
};

const ContactDetailsStep: React.FC = () => {
  return (
    <div>
      <h2 className="text-xl font-semibold mb-4">Contact details</h2>
      <p className="text-gray-600 mb-6">Lorem ipsum dolor sit amet consectetur adipisc.</p>
      <div className="grid grid-cols-2 gap-6">
        <div>
          <label htmlFor="name" className="block mb-2 text-sm font-medium text-gray-700">Name</label>
          <input
            type="text"
            id="name"
            className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-indigo-500"
            placeholder="John Carter"
          />
        </div>
        <div>
          <label htmlFor="email" className="block mb-2 text-sm font-medium text-gray-700">Email</label>
          <input
            type="email"
            id="email"
            className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-indigo-500"
            placeholder="Email address"
          />
        </div>
        <div>
          <label htmlFor="phone" className="block mb-2 text-sm font-medium text-gray-700">Phone Number</label>
          <input
            type="tel"
            id="phone"
            className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-indigo-500"
            placeholder="(123) 456 - 7890"
          />
        </div>
        <div>
          <label htmlFor="company" className="block mb-2 text-sm font-medium text-gray-700">Company</label>
          <input
            type="text"
            id="company"
            className="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-indigo-500"
            placeholder="Company name"
          />
        </div>
      </div>
    </div>
  );
};

export default FirstForm;